# Contributing

Contributions from the community are welcome. To better
understand the code repository, see the [README](https://github.com/ansys/pyfluent/blob/main/README.rst).
While Ansys maintains PyFluent and thoroughly reviews contributions
library package is maintained by Ansys and any submissions are reviewed
thoroughly before merging, it's important to foster a community that can support
user questions and develop new features to make the library a useful tool for
all users. Feel free to add questions and suggestions to the [PyFluent Issues](https://github.com/ansys/pyfluent/issues) page.

For more information on contributing to PyFluent, see the contributing guide in
the [documentation](https://fluent.docs.pyansys.com).
